#[repr(C)]pub enum KnownSignerIdentity {
DHI = 0,
}Expand description
KnownSignerIdentity is an identifier for a special signer identity that is known to the implementation.
Enumeration of values.
Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)]
which helps with FFI.
Variants
DHI = 0