pub struct Network {Show 16 fields
pub name: Option<String>,
pub id: Option<String>,
pub created: Option<String>,
pub scope: Option<String>,
pub driver: Option<String>,
pub enable_ipv4: Option<bool>,
pub enable_ipv6: Option<bool>,
pub ipam: Option<Ipam>,
pub internal: Option<bool>,
pub attachable: Option<bool>,
pub ingress: Option<bool>,
pub config_from: Option<ConfigReference>,
pub config_only: Option<bool>,
pub options: Option<HashMap<String, String>>,
pub labels: Option<HashMap<String, String>>,
pub peers: Option<Vec<PeerInfo>>,
}Fields
name: Option<String>Name of the network.
id: Option<String>ID that uniquely identifies a network on a single machine.
created: Option<String>Date and time at which the network was created in RFC 3339 format with nano-seconds.
scope: Option<String>The level at which the network exists (e.g. swarm for cluster-wide or local for machine level)
driver: Option<String>The name of the driver used to create the network (e.g. bridge, overlay).
enable_ipv4: Option<bool>Whether the network was created with IPv4 enabled.
enable_ipv6: Option<bool>Whether the network was created with IPv6 enabled.
ipam: Option<Ipam>The network’s IP Address Management.
internal: Option<bool>Whether the network is created to only allow internal networking connectivity.
attachable: Option<bool>Whether a global / swarm scope network is manually attachable by regular containers from workers in swarm mode.
ingress: Option<bool>Whether the network is providing the routing-mesh for the swarm cluster.
config_from: Option<ConfigReference>config_only: Option<bool>Whether the network is a config-only network. Config-only networks are placeholder networks for network configurations to be used by other networks. Config-only networks cannot be used directly to run containers or services.
options: Option<HashMap<String, String>>Network-specific options uses when creating the network.
labels: Option<HashMap<String, String>>Metadata specific to the network being created.
peers: Option<Vec<PeerInfo>>List of peer nodes for an overlay network. This field is only present for overlay networks, and omitted for other network types.