pub struct SystemVersion {
pub platform: Option<SystemVersionPlatform>,
pub components: Option<Vec<SystemVersionComponents>>,
pub version: Option<String>,
pub api_version: Option<String>,
pub min_api_version: Option<String>,
pub git_commit: Option<String>,
pub go_version: Option<String>,
pub os: Option<String>,
pub arch: Option<String>,
pub kernel_version: Option<String>,
pub experimental: Option<bool>,
pub build_time: Option<String>,
}Expand description
Response of Engine API: GET "/version"
Fields
platform: Option<SystemVersionPlatform>components: Option<Vec<SystemVersionComponents>>Information about system components
version: Option<String>The version of the daemon
api_version: Option<String>The default (and highest) API version that is supported by the daemon
min_api_version: Option<String>The minimum API version that is supported by the daemon
git_commit: Option<String>The Git commit of the source code that was used to build the daemon
go_version: Option<String>The version Go used to compile the daemon, and the version of the Go runtime in use.
os: Option<String>The operating system that the daemon is running on ("linux" or "windows")
arch: Option<String>Architecture of the daemon, as returned by the Go runtime (GOARCH). A full list of possible values can be found in the Go documentation.
kernel_version: Option<String>The kernel version (uname -r) that the daemon is running on. This field is omitted when empty.
experimental: Option<bool>Indicates if the daemon is started with experimental features enabled. This field is omitted when empty / false.
build_time: Option<String>The date and time that the daemon was compiled.