pub struct ContainerCreateBody {Show 26 fields
pub hostname: Option<String>,
pub domainname: Option<String>,
pub user: Option<String>,
pub attach_stdin: Option<bool>,
pub attach_stdout: Option<bool>,
pub attach_stderr: Option<bool>,
pub exposed_ports: Option<Vec<String>>,
pub tty: Option<bool>,
pub open_stdin: Option<bool>,
pub stdin_once: Option<bool>,
pub env: Option<Vec<String>>,
pub cmd: Option<Vec<String>>,
pub healthcheck: Option<HealthConfig>,
pub args_escaped: Option<bool>,
pub image: Option<String>,
pub volumes: Option<Vec<String>>,
pub working_dir: Option<String>,
pub entrypoint: Option<Vec<String>>,
pub network_disabled: Option<bool>,
pub on_build: Option<Vec<String>>,
pub labels: Option<HashMap<String, String>>,
pub stop_signal: Option<String>,
pub stop_timeout: Option<i64>,
pub shell: Option<Vec<String>>,
pub host_config: Option<HostConfig>,
pub networking_config: Option<NetworkingConfig>,
}Fields
hostname: Option<String>The hostname to use for the container, as a valid RFC 1123 hostname.
domainname: Option<String>The domain name to use for the container.
user: Option<String>Commands run as this user inside the container. If omitted, commands run as the user specified in the image the container was started from. Can be either user-name or UID, and optional group-name or GID, separated by a colon (<user-name|UID>[<:group-name|GID>]).
attach_stdin: Option<bool>Whether to attach to stdin.
attach_stdout: Option<bool>Whether to attach to stdout.
attach_stderr: Option<bool>Whether to attach to stderr.
exposed_ports: Option<Vec<String>>An object mapping ports to an empty object in the form: {\"<port>/<tcp|udp|sctp>\": {}}
tty: Option<bool>Attach standard streams to a TTY, including stdin if it is not closed.
open_stdin: Option<bool>Open stdin
stdin_once: Option<bool>Close stdin after one attached client disconnects
env: Option<Vec<String>>A list of environment variables to set inside the container in the form [\"VAR=value\", ...]. A variable without = is removed from the environment, rather than to have an empty value.
cmd: Option<Vec<String>>Command to run specified as a string or an array of strings.
healthcheck: Option<HealthConfig>args_escaped: Option<bool>Command is already escaped (Windows only)
image: Option<String>The name (or reference) of the image to use when creating the container, or which was used when the container was created.
volumes: Option<Vec<String>>An object mapping mount point paths inside the container to empty objects.
working_dir: Option<String>The working directory for commands to run in.
entrypoint: Option<Vec<String>>The entry point for the container as a string or an array of strings. If the array consists of exactly one empty string ([\"\"]) then the entry point is reset to system default (i.e., the entry point used by docker when there is no ENTRYPOINT instruction in the Dockerfile).
network_disabled: Option<bool>Disable networking for the container.
on_build: Option<Vec<String>>ONBUILD metadata that were defined in the image’s Dockerfile.
labels: Option<HashMap<String, String>>User-defined key/value metadata.
stop_signal: Option<String>Signal to stop a container as a string or unsigned integer.
stop_timeout: Option<i64>Timeout to stop a container in seconds.
shell: Option<Vec<String>>Shell for when RUN, CMD, and ENTRYPOINT uses a shell.
host_config: Option<HostConfig>networking_config: Option<NetworkingConfig>Trait Implementations
Sourceimpl Clone for ContainerCreateBody
impl Clone for ContainerCreateBody
Sourcefn clone(&self) -> ContainerCreateBody
fn clone(&self) -> ContainerCreateBody
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more