ImageInspect

Struct ImageInspect 

pub struct ImageInspect {
Show 18 fields pub id: Option<String>, pub descriptor: Option<OciDescriptor>, pub manifests: Option<Vec<ImageManifestSummary>>, pub identity: Option<Identity>, pub repo_tags: Option<Vec<String>>, pub repo_digests: Option<Vec<String>>, pub comment: Option<String>, pub created: Option<String>, pub author: Option<String>, pub config: Option<ImageConfig>, pub architecture: Option<String>, pub variant: Option<String>, pub os: Option<String>, pub os_version: Option<String>, pub size: Option<i64>, pub graph_driver: Option<DriverData>, pub root_fs: Option<ImageInspectRootFs>, pub metadata: Option<ImageInspectMetadata>,
}
Information about an image in the local image cache.

Fields

id: Option<String>

ID is the content-addressable ID of an image. This identifier is a content-addressable digest calculated from the image’s configuration (which includes the digests of layers used by the image). Note that this digest differs from the RepoDigests below, which holds digests of image manifests that reference the image.

descriptor: Option<OciDescriptor>

Descriptor is an OCI descriptor of the image target. In case of a multi-platform image, this descriptor points to the OCI index or a manifest list. This field is only present if the daemon provides a multi-platform image store. WARNING: This is experimental and may change at any time without any backward compatibility.

manifests: Option<Vec<ImageManifestSummary>>

Manifests is a list of image manifests available in this image. It provides a more detailed view of the platform-specific image manifests or other image-attached data like build attestations. Only available if the daemon provides a multi-platform image store and the manifests option is set in the inspect request. WARNING: This is experimental and may change at any time without any backward compatibility.

identity: Option<Identity>

Identity holds information about the identity and origin of the image. This is trusted information verified by the daemon and cannot be modified by tagging an image to a different name.

repo_tags: Option<Vec<String>>

List of image names/tags in the local image cache that reference this image. Multiple image tags can refer to the same image, and this list may be empty if no tags reference the image, in which case the image is "untagged", in which case it can still be referenced by its ID.

repo_digests: Option<Vec<String>>

List of content-addressable digests of locally available image manifests that the image is referenced from. Multiple manifests can refer to the same image. These digests are usually only available if the image was either pulled from a registry, or if the image was pushed to a registry, which is when the manifest is generated and its digest calculated.

comment: Option<String>

Optional message that was set when committing or importing the image.

created: Option<String>

Date and time at which the image was created, formatted in RFC 3339 format with nano-seconds. This information is only available if present in the image, and omitted otherwise.

author: Option<String>

Name of the author that was specified when committing the image, or as specified through MAINTAINER (deprecated) in the Dockerfile.

config: Option<ImageConfig>architecture: Option<String>

Hardware CPU architecture that the image runs on.

variant: Option<String>

CPU architecture variant (presently ARM-only).

os: Option<String>

Operating System the image is built to run on.

os_version: Option<String>

Operating System version the image is built to run on (especially for Windows).

size: Option<i64>

Total size of the image including all layers it is composed of.

graph_driver: Option<DriverData>root_fs: Option<ImageInspectRootFs>metadata: Option<ImageInspectMetadata>