InspectImageOptionsBuilder

Struct InspectImageOptionsBuilder 

pub struct InspectImageOptionsBuilder { /* private fields */ }
Builder for the ImageInspect API query parameter.

Inspect an image.

Examples

use bollard_stubs::query_parameters::InspectImageOptionsBuilder;

let params = InspectImageOptionsBuilder::new()
//  .manifests(/* ... */)
//  .platform(/* ... */)
    .build();

Implementations

Source

impl InspectImageOptionsBuilder

pub fn new() -> InspectImageOptionsBuilder

Construct a builder of query parameters for InspectImageOptions using defaults.

pub fn manifests(self, manifests: bool) -> InspectImageOptionsBuilder

Include Manifests in the image summary.

The manifests and platform options are mutually exclusive, and an error is produced if both are set.

pub fn platform(self, platform: &str) -> InspectImageOptionsBuilder

JSON-encoded OCI platform to select the platform-variant. If omitted, it defaults to any locally available platform, prioritizing the daemon’s host platform.

If the daemon provides a multi-platform image store, this selects the platform-variant to show inspect. If the image is a single-platform image, or if the multi-platform image does not provide a variant matching the given platform, an error is returned.

The platform and manifests options are mutually exclusive, and an error is produced if both are set.

Example: {"os": "linux", "architecture": "arm", "variant": "v5"}

pub fn build(self) -> InspectImageOptions

Consume this builder and use the InspectImageOptions as parameter to the ImageInspect API