pub struct PruneContainersOptionsBuilder { /* private fields */ }Expand description
Builder for the ContainerPrune API query parameter.
Delete stopped containers.
Examples
use bollard_stubs::query_parameters::PruneContainersOptionsBuilder;
let params = PruneContainersOptionsBuilder::new()
// .filters(/* ... */)
.build();Implementations
Sourceimpl PruneContainersOptionsBuilder
impl PruneContainersOptionsBuilder
Sourcepub fn new() -> PruneContainersOptionsBuilder
pub fn new() -> PruneContainersOptionsBuilder
Construct a builder of query parameters for PruneContainersOptions using defaults.
Sourcepub fn filters(
self,
filters: &HashMap<impl Into<String> + Clone, Vec<impl Into<String> + Clone>>,
) -> PruneContainersOptionsBuilder
pub fn filters( self, filters: &HashMap<impl Into<String> + Clone, Vec<impl Into<String> + Clone>>, ) -> PruneContainersOptionsBuilder
Filters to process on the prune list, encoded as JSON (a map[string][]string).
Available filters:
until=<timestamp>Prune containers created before this timestamp. The<timestamp>can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g.10m,1h30m) computed relative to the daemon machine’s time.label(label=<key>,label=<key>=<value>,label!=<key>, orlabel!=<key>=<value>) Prune containers with (or without, in caselabel!=...is used) the specified labels.
Sourcepub fn build(self) -> PruneContainersOptions
pub fn build(self) -> PruneContainersOptions
Consume this builder and use the PruneContainersOptions as parameter to the
ContainerPrune API