UpdateServiceOptionsBuilder

Struct UpdateServiceOptionsBuilder 

pub struct UpdateServiceOptionsBuilder { /* private fields */ }
Builder for the ServiceUpdate API query parameter.

Update a service.

Examples

use bollard_stubs::query_parameters::UpdateServiceOptionsBuilder;

let params = UpdateServiceOptionsBuilder::new()
//  .version(/* ... */)
//  .registry_auth_from(/* ... */)
//  .rollback(/* ... */)
    .build();

Implementations

Source

impl UpdateServiceOptionsBuilder

pub fn new() -> UpdateServiceOptionsBuilder

Construct a builder of query parameters for UpdateServiceOptions using defaults.

pub fn version(self, version: i32) -> UpdateServiceOptionsBuilder

The version number of the service object being updated. This is required to avoid conflicting writes. This version number should be the value as currently set on the service before the update. You can find the current version by calling GET /services/{id}

pub fn registry_auth_from( self, registry_auth_from: &str, ) -> UpdateServiceOptionsBuilder

If the X-Registry-Auth header is not specified, this parameter indicates where to find registry authorization credentials.

pub fn rollback(self, rollback: &str) -> UpdateServiceOptionsBuilder

Set to this parameter to previous to cause a server-side rollback to the previous service spec. The supplied spec will be ignored in this case.

pub fn build(self) -> UpdateServiceOptions

Consume this builder and use the UpdateServiceOptions as parameter to the ServiceUpdate API