#[repr(C)]pub enum SignatureTimestampType {
TLOG = 0,
TIMESTAMPAUTHORITY = 1,
}Expand description
SignatureTimestampType is the type of timestamp used in the signature.
Enumeration of values.
Since this enum’s variants do not hold data, we can easily define them them as #[repr(C)]
which helps with FFI.
Variants