pub struct ClusterVolumeSpecAccessMode {
pub scope: Option<ClusterVolumeSpecAccessModeScopeEnum>,
pub sharing: Option<ClusterVolumeSpecAccessModeSharingEnum>,
pub mount_volume: Option<HashMap<(), ()>>,
pub secrets: Option<Vec<ClusterVolumeSpecAccessModeSecrets>>,
pub accessibility_requirements: Option<ClusterVolumeSpecAccessModeAccessibilityRequirements>,
pub capacity_range: Option<ClusterVolumeSpecAccessModeCapacityRange>,
pub availability: Option<ClusterVolumeSpecAccessModeAvailabilityEnum>,
}Expand description
Defines how the volume is used by tasks.
Fields
scope: Option<ClusterVolumeSpecAccessModeScopeEnum>The set of nodes this volume can be used on at one time. - single The volume may only be scheduled to one node at a time. - multi the volume may be scheduled to any supported number of nodes at a time.
sharing: Option<ClusterVolumeSpecAccessModeSharingEnum>The number and way that different tasks can use this volume at one time. - none The volume may only be used by one task at a time. - readonly The volume may be used by any number of tasks, but they all must mount the volume as readonly - onewriter The volume may be used by any number of tasks, but only one may mount it as read/write. - all The volume may have any number of readers and writers.
mount_volume: Option<HashMap<(), ()>>Options for using this volume as a Mount-type volume. Either MountVolume or BlockVolume, but not both, must be present. properties: FsType: type: "string" description: | Specifies the filesystem type for the mount volume. Optional. MountFlags: type: "array" description: | Flags to pass when mounting the volume. Optional. items: type: "string" BlockVolume: type: "object" description: | Options for using this volume as a Block-type volume. Intentionally empty.
secrets: Option<Vec<ClusterVolumeSpecAccessModeSecrets>>Swarm Secrets that are passed to the CSI storage plugin when operating on this volume.
accessibility_requirements: Option<ClusterVolumeSpecAccessModeAccessibilityRequirements>capacity_range: Option<ClusterVolumeSpecAccessModeCapacityRange>availability: Option<ClusterVolumeSpecAccessModeAvailabilityEnum>The availability of the volume for use in tasks. - active The volume is fully available for scheduling on the cluster - pause No new workloads should use the volume, but existing workloads are not stopped. - drain All workloads using this volume should be stopped and rescheduled, and no new ones should be started.